---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2009-01-28;2
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20090128&codiceRedaz=009G0010&dataVigenza=20251104
dataGU: 20090128
codiceRedaz: 009G0010
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 29 novembre 2008, n. 185, recante misure urgenti per il sostegno a famiglie, lavoro, occupazione e impresa e per ridisegnare in funzione anti-crisi il quadro strategico nazionale.

La Camera dei deputati ed il Senato della Repubblica hanno pprovato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 29 novembre 2008, n. 185, recante misure urgenti per il sostegno a famiglie, lavoro, occupazione e impresa e per ridisegnare in funzione anti-crisi il quadro strategico nazionale, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

